===============
Further reading
===============

This chapter has introduced only the basics of the Python programming language. You are encouraged to look at the standard Python documentation on the official Python website (https://www.python.org) for more information. In addition, you may find it beneficial to work through the online tutorial on the Python website. A Python reference book will go into more details on object-oriented programming techniques; see :doc:`/python-resources` for a list of Python books.

There are many resources available from the Python community. You should look at the official Python website (https://www.python.org) to see the various Python packages that are available publicly.